@@ -1,6 +1,6 @@
 package Bundle::Interchange;
 
-$VERSION = '0.07';
+$VERSION = '1.00';
 
 1;
 
@@ -8,7 +8,7 @@ __END__
 
 =head1 NAME
 
-Bundle::Interchange - A bundle of the modules nice to have for Interchange.
+Bundle::Interchange - A bundle of the modules nice to have for Interchange 5.
 
 =head1 SYNOPSIS
 
@@ -30,10 +30,14 @@ Parse::RecDescent
 
 OLE::Storage_Lite
 
+Bundle::LWP
+
 Term::ReadKey
 
 Term::ReadLine::Perl
 
+Text::Query
+
 Image::Size
 
 DBI
@@ -42,15 +46,11 @@ Safe::Hole
 
 Tie::ShadowHash
 
-Business::UPS
-
 IO::Scalar
 
-SQL::Statement::Hash
-
 Storable
 
-Bundle::LWP
+Business::UPS
 
 Spreadsheet::ParseExcel
 
@@ -58,7 +58,7 @@ Spreadsheet::WriteExcel
 
 =head1 DESCRIPTION
 
-This bundle installs the prerequisites for Interchange as well as some
+This bundle installs the prerequisites for Interchange 5 as well as some
 modules that are not strictly necessary.
 
 (Interchange was formerly known as Minivend.)
@@ -73,15 +73,18 @@ you will need these modules.
 
 =over 4
 
-=item MD5
+=item Digest::MD5
 This module is used to generate unique cache keys. If you don't have it,
 then keys will be computed with a checksum that has a very low but not
 infinitesimal chance of causing a cache conflict.
 
+=item MIME::Base64
+
+Used for decoding HTTP authorization, also part of Bundle::LWP.
+
 =item Bundle::LWP
-Certain parts of these modules (URI::URL and MIME::Base64) are required
-for Interchange's internal HTTP server. Also, Business::UPS, for calculating
-shipping, requires this.
+Business::UPS, for calculating shipping, requires this. The [get-url ...]
+UserTag and most payment gateways also need LWP.
 
 =item Storable
 If you have this module session save speed increases by anywhere from 25-60%.
@@ -90,8 +93,16 @@ Highly recommended for busy systems.
 =item Business::UPS
 Enables lookup of shipping costs directly from www.ups.com.
 
-=item SQL::Statement
-Enables SQL-style search query statements for Interchange.
+=item HTML::Parser
+
+The HTML::Entities module, which is part of this package, is used to
+parse HTML entities for substitution. URI::URL and HTML::TagSet are
+prerequisites.
+
+=item Text::Query
+
+Gives Altavista-style search language with AND, OR, NOT, and NEAR and
+full parentheses nesting.
 
 =item Safe::Hole
 This helps Interchange deal with the object-creation restrictions
@@ -102,14 +113,27 @@ Most people want to use SQL with Interchange, and this is a requirement.
 You will also need the appropriate DBD module, i.e. DBD::mysql to support
 B<MySQL>.
 
-=item Term::ReadKey
-Helps Term::ReadLine::Perl generate completions and editing.
+=item Spreadsheet::ParseExcel
+
+Allows upload of XLS spreadsheets in UI. IO::Scalar and OLE::Storage_Lite
+are prerequisites.
+
+=item Spreadsheet::WriteExcel
+
+Allows creation of XLS spreadsheets for download in UI.
 
 =item Term::ReadLine::Perl
+
 Gives you filename completion and command history in the makecat program.
 Not used otherwise.
 
+=item Term::ReadKey
+
+Helps Term::ReadLine::Perl generate completions and editing in makecat.
+Not used otherwise.
+
+=back
 
 =head1 AUTHOR
 
-Mike Heins, <heins@akopia.com>
+Mike Heins, <mikeh@perusion.net>
